Index: COPYING
===================================================================
--- COPYING	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ COPYING	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -1,11 +1,11 @@
-		    GNU GENERAL PUBLIC LICENSE
-		       Version 2, June 1991
-
- Copyright (C) 1989, 1991 Free Software Foundation, Inc.
-     59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+                    GNU GENERAL PUBLIC LICENSE
+                       Version 2, June 1991
+
+ Copyright (C) 1989, 1991 Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  Everyone is permitted to copy and distribute verbatim copies
  of this license document, but changing it is not allowed.
 
-			    Preamble
+                            Preamble
 
   The licenses for most software are designed to take away your
@@ -16,5 +16,5 @@
 Foundation's software and to any other program whose authors commit to
 using it.  (Some other Free Software Foundation software is covered by
-the GNU Library General Public License instead.)  You can apply it to
+the GNU Lesser General Public License instead.)  You can apply it to
 your programs, too.
 
@@ -57,6 +57,5 @@
 modification follow.
 
-
-		    GNU GENERAL PUBLIC LICENSE
+                    GNU GENERAL PUBLIC LICENSE
    TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
 
@@ -113,5 +112,4 @@
     the Program is not required to print an announcement.)
 
-
 These requirements apply to the modified work as a whole.  If
 identifiable sections of that work are not derived from the Program,
@@ -171,5 +169,4 @@
 distribution of the source code, even though third parties are not
 compelled to copy the source along with the object code.
-
 
   4. You may not copy, modify, sublicense, or distribute the Program
@@ -230,5 +227,4 @@
 be a consequence of the rest of this License.
 
-
   8. If the distribution and/or use of the Program is restricted in
 certain countries either by patents or by copyrighted interfaces, the
@@ -260,5 +256,5 @@
 of promoting the sharing and reuse of software generally.
 
-			    NO WARRANTY
+                            NO WARRANTY
 
   11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
@@ -282,8 +278,7 @@
 POSSIBILITY OF SUCH DAMAGES.
 
-		     END OF TERMS AND CONDITIONS
-
-
-	    How to Apply These Terms to Your New Programs
+                     END OF TERMS AND CONDITIONS
+
+            How to Apply These Terms to Your New Programs
 
   If you develop a new program, and you want it to be of the greatest
@@ -309,8 +304,7 @@
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 Also add information on how to contact you by electronic and paper mail.
@@ -319,5 +313,5 @@
 when it starts in an interactive mode:
 
-    Gnomovision version 69, Copyright (C) year  name of author
+    Gnomovision version 69, Copyright (C) year name of author
     Gnomovision comes with ABSOLUTELY NO WARRANTY; for details type `show w'.
     This is free software, and you are welcome to redistribute it
@@ -342,4 +336,4 @@
 proprietary programs.  If your program is a subroutine library, you may
 consider it more useful to permit linking proprietary applications with the
-library.  If this is what you want to do, use the GNU Library General
+library.  If this is what you want to do, use the GNU Lesser General
 Public License instead of this License.
Index: bitlbee.c
===================================================================
--- bitlbee.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ bitlbee.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: bitlbee.h
===================================================================
--- bitlbee.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ bitlbee.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: commands.h
===================================================================
--- commands.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ commands.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: conf.c
===================================================================
--- conf.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ conf.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: conf.h
===================================================================
--- conf.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ conf.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: dcc.c
===================================================================
--- dcc.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ dcc.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -18,6 +18,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -523,5 +523,5 @@
 		
 		host = ctcp[3];
-		while( *host && isdigit( *host ) ) host++; /* Just digits? */
+		while( *host && g_ascii_isdigit( *host ) ) host++; /* Just digits? */
 		if( *host == '\0' )
 		{
Index: dcc.h
===================================================================
--- dcc.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ dcc.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -19,6 +19,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: help.c
===================================================================
--- help.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ help.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: help.h
===================================================================
--- help.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ help.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: ipc.c
===================================================================
--- ipc.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ ipc.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: ipc.h
===================================================================
--- ipc.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ ipc.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: irc.c
===================================================================
--- irc.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: irc.h
===================================================================
--- irc.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: irc_channel.c
===================================================================
--- irc_channel.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc_channel.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -575,5 +575,5 @@
 	
 	/* Scan for non-whitespace chars followed by a colon: */
-	for( s = msg; *s && !isspace( *s ) && *s != ':' && *s != ','; s ++ ) {}
+	for( s = msg; *s && !g_ascii_isspace( *s ) && *s != ':' && *s != ','; s ++ ) {}
 	
 	if( *s == ':' || *s == ',' )
@@ -583,5 +583,5 @@
 		memset( to, 0, sizeof( to ) );
 		strncpy( to, msg, s - msg );
-		while( *(++s) && isspace( *s ) ) {}
+		while( *(++s) && g_ascii_isspace( *s ) ) {}
 		msg = s;
 		
Index: irc_commands.c
===================================================================
--- irc_commands.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc_commands.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: irc_im.c
===================================================================
--- irc_im.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc_im.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -73,5 +73,5 @@
 		{
 			char *s;
-			for( s = bu->ic->acc->tag; isalnum( *s ); s ++ );
+			for( s = bu->ic->acc->tag; g_ascii_isalnum( *s ); s ++ );
 			/* Only use the tag if we got to the end of the string.
 			   (So allow alphanumerics only. Hopefully not too
@@ -316,5 +316,5 @@
 	   TODO(wilmer): Do the same with away msgs again! */
 	for( s = iu->fullname; *s; s ++ )
-		if( isspace( *s ) ) *s = ' ';
+		if( g_ascii_isspace( *s ) ) *s = ' ';
 	
 	if( ( bu->ic->flags & OPT_LOGGED_IN ) && set_getbool( &bee->set, "display_namechanges" ) )
Index: irc_send.c
===================================================================
--- irc_send.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc_send.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: irc_user.c
===================================================================
--- irc_user.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc_user.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: irc_util.c
===================================================================
--- irc_util.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ irc_util.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -42,7 +42,7 @@
 	
 	/* \d+ */
-	if( !isdigit( *s ) )
+	if( !g_ascii_isdigit( *s ) )
 		return SET_INVALID;
-	while( *s && isdigit( *s ) ) s ++;
+	while( *s && g_ascii_isdigit( *s ) ) s ++;
 	
 	/* EOS? */
@@ -56,7 +56,7 @@
 	
 	/* \d+ */
-	if( !isdigit( *s ) )
+	if( !g_ascii_isdigit( *s ) )
 		return SET_INVALID;
-	while( *s && isdigit( *s ) ) s ++;
+	while( *s && g_ascii_isdigit( *s ) ) s ++;
 	
 	/* EOS */
Index: lib/events.h
===================================================================
--- lib/events.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/events.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: lib/events_glib.c
===================================================================
--- lib/events_glib.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/events_glib.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -22,6 +22,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/events_libevent.c
===================================================================
--- lib/events_libevent.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/events_libevent.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -22,6 +22,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/http_client.c
===================================================================
--- lib/http_client.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/http_client.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -345,10 +345,10 @@
 		/* Might be a \r\n from the last chunk. */
 		s = chunk;
-		while( isspace( *s ) )
+		while( g_ascii_isspace( *s ) )
 			s ++;
 		/* Chunk length. Might be incomplete. */
 		if( s < eos && sscanf( s, "%x", &clen ) != 1 )
 			return CR_ERROR;
-		while( isxdigit( *s ) )
+		while( g_ascii_isxdigit( *s ) )
 			s ++;
 		
Index: lib/http_client.h
===================================================================
--- lib/http_client.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/http_client.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/ini.c
===================================================================
--- lib/ini.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/ini.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 #define BITLBEE_CORE
@@ -63,9 +63,9 @@
 	char *e;
 
-	while( isspace( *in ) )
+	while( g_ascii_isspace( *in ) )
 		in++;
 
 	e = in + strlen( in ) - 1;
-	while( e > in && isspace( *e ) )
+	while( e > in && g_ascii_isspace( *e ) )
 		e--;
 	e[1] = 0;
Index: lib/ini.h
===================================================================
--- lib/ini.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/ini.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/json.c
===================================================================
--- lib/json.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/json.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -53,5 +53,5 @@
 static unsigned char hex_value (json_char c)
 {
-   if (isdigit(c))
+   if (g_ascii_isdigit(c))
       return c - '0';
 
@@ -609,5 +609,5 @@
                      default:
 
-                        if (isdigit (b) || b == '-')
+                        if (g_ascii_isdigit (b) || b == '-')
                         {
                            if (!new_value (&state, &top, &root, &alloc, json_integer))
@@ -616,5 +616,5 @@
                            if (!state.first_pass)
                            {
-                              while (isdigit (b) || b == '+' || b == '-'
+                              while (g_ascii_isdigit (b) || b == '+' || b == '-'
                                         || b == 'e' || b == 'E' || b == '.')
                               {
@@ -706,5 +706,5 @@
             case json_double:
 
-               if (isdigit (b))
+               if (g_ascii_isdigit (b))
                {
                   ++ num_digits;
Index: lib/misc.h
===================================================================
--- lib/misc.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/misc.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/proxy.c
===================================================================
--- lib/proxy.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/proxy.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -17,5 +17,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: lib/proxy.h
===================================================================
--- lib/proxy.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/proxy.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: lib/ssl_client.h
===================================================================
--- lib/ssl_client.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/ssl_client.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/ssl_gnutls.c
===================================================================
--- lib/ssl_gnutls.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/ssl_gnutls.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -318,5 +318,5 @@
 	gnutls_set_default_priority( conn->session );
 	gnutls_credentials_set( conn->session, GNUTLS_CRD_CERTIFICATE, xcred );
-	if( conn->hostname && !isdigit( conn->hostname[0] ) )
+	if( conn->hostname && !g_ascii_isdigit( conn->hostname[0] ) )
 		gnutls_server_name_set( conn->session, GNUTLS_NAME_DNS,
 		                        conn->hostname, strlen( conn->hostname ) );
Index: lib/ssl_nss.c
===================================================================
--- lib/ssl_nss.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/ssl_nss.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -22,6 +22,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/ssl_openssl.c
===================================================================
--- lib/ssl_openssl.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/ssl_openssl.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -159,5 +159,5 @@
 	SSL_set_fd( conn->ssl, conn->fd );
 	
-	if( conn->hostname && !isdigit( conn->hostname[0] ) )
+	if( conn->hostname && !g_ascii_isdigit( conn->hostname[0] ) )
 		SSL_set_tlsext_host_name( conn->ssl, conn->hostname );
 	
Index: lib/url.c
===================================================================
--- lib/url.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/url.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: lib/url.h
===================================================================
--- lib/url.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/url.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: log.c
===================================================================
--- log.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ log.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: log.h
===================================================================
--- log.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ log.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: nick.c
===================================================================
--- nick.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ nick.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -41,5 +41,5 @@
 	do {
 		if (*orig != ' ')
-			new[i++] = tolower( *orig );
+			new[i++] = g_ascii_tolower( *orig );
 	}
 	while (*(orig++));
@@ -144,9 +144,9 @@
 				fmt += 2;
 			}
-			else if( isdigit( *fmt ) )
+			else if( g_ascii_isdigit( *fmt ) )
 			{
 				len = 0;
 				/* Grab a number. */
-				while( isdigit( *fmt ) )
+				while( g_ascii_isdigit( *fmt ) )
 					len = len * 10 + ( *(fmt++) - '0' );
 			}
@@ -331,5 +331,5 @@
 		}
 	}
-	if( isdigit( nick[0] ) )
+	if( g_ascii_isdigit( nick[0] ) )
 	{
 		char *orig;
@@ -351,5 +351,5 @@
 	
 	/* Empty/long nicks are not allowed, nor numbers at [0] */
-	if( !*nick || isdigit( nick[0] ) || strlen( nick ) > MAX_NICK_LENGTH )
+	if( !*nick || g_ascii_isdigit( nick[0] ) || strlen( nick ) > MAX_NICK_LENGTH )
 		return 0;
 	
Index: nick.h
===================================================================
--- nick.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ nick.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: otr.c
===================================================================
--- otr.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ otr.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -36,6 +36,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -1470,5 +1470,5 @@
 int hexval(char a)
 {
-	int x=tolower(a);
+	int x=g_ascii_tolower(a);
 	
 	if(x>='a' && x<='f')
@@ -1557,5 +1557,5 @@
 	for(i=0; args[i]; i++) {
 		for(j=0; args[i][j]; j++) {
-			char c = toupper(args[i][j]);
+			char c = g_ascii_toupper(args[i][j]);
 			
 			if(n>=40) {
@@ -1621,5 +1621,5 @@
 	for(i=0; args[i]; i++) {
 		for(j=0; args[i][j]; j++) {
-			char c = toupper(args[i][j]);
+			char c = g_ascii_toupper(args[i][j]);
 			
 			if(n>=40) {
Index: otr.h
===================================================================
--- otr.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ otr.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -25,6 +25,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/account.c
===================================================================
--- protocols/account.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/account.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -81,5 +81,5 @@
 	if( strcmp( prpl->name, "oscar" ) == 0 )
 	{
-		if( isdigit( a->user[0] ) )
+		if( g_ascii_isdigit( a->user[0] ) )
 			strcpy( tag, "icq" );
 		else
@@ -417,5 +417,5 @@
 	
 	/* Format: /[0-9]+([*+][0-9]+(<[0-9+])?)?/ */
-	while( *value && isdigit( *value ) )
+	while( *value && g_ascii_isdigit( *value ) )
 		p->start = p->start * 10 + *value++ - '0';
 	
@@ -433,5 +433,5 @@
 	
 	/* + or * the delay by this number every time. */
-	while( *value && isdigit( *value ) )
+	while( *value && g_ascii_isdigit( *value ) )
 		p->step = p->step * 10 + *value++ - '0';
 	
@@ -444,5 +444,5 @@
 	p->max = 0;
 	value ++;
-	while( *value && isdigit( *value ) )
+	while( *value && g_ascii_isdigit( *value ) )
 		p->max = p->max * 10 + *value++ - '0';
 	
Index: protocols/account.h
===================================================================
--- protocols/account.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/account.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/bee.c
===================================================================
--- protocols/bee.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/bee.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/bee.h
===================================================================
--- protocols/bee.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/bee.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/bee_chat.c
===================================================================
--- protocols/bee_chat.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/bee_chat.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/bee_ft.c
===================================================================
--- protocols/bee_ft.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/bee_ft.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -18,6 +18,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/bee_user.c
===================================================================
--- protocols/bee_user.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/bee_user.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/ft.h
===================================================================
--- protocols/ft.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/ft.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/jabber/jabber_util.c
===================================================================
--- protocols/jabber/jabber_util.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/jabber/jabber_util.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -321,5 +321,5 @@
 			return FALSE;
 		}
-		if( tolower( jid1[i] ) != tolower( jid2[i] ) )
+		if( g_ascii_tolower( jid1[i] ) != g_ascii_tolower( jid2[i] ) )
 		{
 			return FALSE;
@@ -342,5 +342,5 @@
 	   it's Unicode but feck Unicode. :-P So stop once we see a slash. */
 	for( i = 0; i < len && orig[i] != '/' ; i ++ )
-		new[i] = tolower( orig[i] );
+		new[i] = g_ascii_tolower( orig[i] );
 	for( ; orig[i]; i ++ )
 		new[i] = orig[i];
Index: protocols/jabber/sasl.c
===================================================================
--- protocols/jabber/sasl.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/jabber/sasl.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -187,5 +187,5 @@
 	len = strlen( field );
 	
-	while( isspace( *data ) || *data == ',' )
+	while( g_ascii_isspace( *data ) || *data == ',' )
 		data ++;
 	
@@ -210,5 +210,5 @@
 			if( data[i] == ',' )
 			{
-				while( isspace( data[i] ) || data[i] == ',' )
+				while( g_ascii_isspace( data[i] ) || data[i] == ',' )
 					i ++;
 				
Index: protocols/msn/invitation.c
===================================================================
--- protocols/msn/invitation.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/invitation.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -21,6 +21,6 @@
  You should have received a copy of the GNU General Public License with
  the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
- if not, write to the Free Software Foundation, Inc., 59 Temple Place,
- Suite 330, Boston, MA  02111-1307  USA
+ if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+ Fifth Floor, Boston, MA  02110-1301  USA
  */
 
Index: protocols/msn/invitation.h
===================================================================
--- protocols/msn/invitation.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/invitation.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
  You should have received a copy of the GNU General Public License with
  the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
- if not, write to the Free Software Foundation, Inc., 59 Temple Place,
- Suite 330, Boston, MA  02111-1307  USA
+ if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+ Fifth Floor, Boston, MA  02110-1301  USA
  */
 
Index: protocols/msn/msn.c
===================================================================
--- protocols/msn/msn.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/msn.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -377,5 +377,5 @@
 	g_tree_insert( md->domaintree, bu->handle, bu );
 	
-	for( handle = bu->handle; isdigit( *handle ); handle ++ );
+	for( handle = bu->handle; g_ascii_isdigit( *handle ); handle ++ );
 	if( *handle == ':' )
 	{
Index: protocols/msn/msn.h
===================================================================
--- protocols/msn/msn.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/msn.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/msn/msn_util.c
===================================================================
--- protocols/msn/msn_util.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/msn_util.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/msn/ns.c
===================================================================
--- protocols/msn/ns.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/ns.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -581,5 +581,5 @@
 		ic->flags |= OPT_PONGED;
 	}
-	else if( isdigit( cmd[0][0] ) )
+	else if( g_ascii_isdigit( cmd[0][0] ) )
 	{
 		int num = atoi( cmd[0] );
@@ -997,5 +997,5 @@
 	/* This might be a federated contact. Get its network number,
 	   prefixed to bu->handle with a colon. Default is 1. */
-	for( handle = bu->handle; isdigit( *handle ); handle ++ )
+	for( handle = bu->handle; g_ascii_isdigit( *handle ); handle ++ )
 		type = type * 10 + *handle - '0';
 	if( *handle == ':' )
Index: protocols/msn/sb.c
===================================================================
--- protocols/msn/sb.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/sb.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -506,5 +506,5 @@
 	else if( strcmp( cmd[0], "CAL" ) == 0 )
 	{
-		if( num_parts < 4 || !isdigit( cmd[3][0] ) )
+		if( num_parts < 4 || !g_ascii_isdigit( cmd[3][0] ) )
 		{
 			msn_sb_destroy( sb );
@@ -645,5 +645,5 @@
 		}
 	}
-	else if( isdigit( cmd[0][0] ) )
+	else if( g_ascii_isdigit( cmd[0][0] ) )
 	{
 		int num = atoi( cmd[0] );
Index: protocols/msn/soap.c
===================================================================
--- protocols/msn/soap.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/soap.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -23,6 +23,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/msn/soap.h
===================================================================
--- protocols/msn/soap.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/soap.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -23,6 +23,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/msn/tables.c
===================================================================
--- protocols/msn/tables.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/msn/tables.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/nogaim.c
===================================================================
--- protocols/nogaim.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/nogaim.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -28,6 +28,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/nogaim.h
===================================================================
--- protocols/nogaim.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/nogaim.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -32,6 +32,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: protocols/oscar/auth.c
===================================================================
--- protocols/oscar/auth.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/oscar/auth.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -125,5 +125,5 @@
 		return -EINVAL;
 
-	if (isdigit(sn[0]) && set_getbool(&ic->acc->set, "old_icq_auth"))
+	if (g_ascii_isdigit(sn[0]) && set_getbool(&ic->acc->set, "old_icq_auth"))
 		return goddamnicq(sess, conn, sn);
 
Index: protocols/oscar/oscar.c
===================================================================
--- protocols/oscar/oscar.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/oscar/oscar.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -19,5 +19,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
@@ -368,5 +368,5 @@
 {
 	set_t *s;
-	gboolean icq = isdigit(acc->user[0]);
+	gboolean icq = g_ascii_isdigit(acc->user[0]);
 	
 	if (icq) {
@@ -394,5 +394,5 @@
 	struct oscar_data *odata = ic->proto_data = g_new0(struct oscar_data, 1);
 
-	if (isdigit(acc->user[0]))
+	if (g_ascii_isdigit(acc->user[0]))
 		odata->icq = TRUE;
 	else
@@ -2500,9 +2500,9 @@
 	char * chatname, *s;
 	
-	chatname = g_strdup_printf("%s%s%d", isdigit(*ic->acc->user) ? "icq" : "",
+	chatname = g_strdup_printf("%s%s%d", g_ascii_isdigit(*ic->acc->user) ? "icq" : "",
 	                           ic->acc->user, chat_id++);
 	
 	for (s = chatname; *s; s ++)
-		if (!isalnum(*s))
+		if (!g_ascii_isalnum(*s))
 			*s = '0';
 	
Index: protocols/oscar/oscar_util.c
===================================================================
--- protocols/oscar/oscar_util.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/oscar/oscar_util.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -57,5 +57,5 @@
 				curPtr2++;
 		} else {
-			if ( toupper(*curPtr1) != toupper(*curPtr2))
+			if ( g_ascii_toupper(*curPtr1) != g_ascii_toupper(*curPtr2))
 				return 1;
 			curPtr1++;
Index: protocols/purple/purple.c
===================================================================
--- protocols/purple/purple.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/purple/purple.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -61,5 +61,5 @@
 		while( *a == '_' ) a ++;
 		while( *b == '_' ) b ++;
-		if( tolower( *a ) != tolower( *b ) )
+		if( g_ascii_tolower( *a ) != g_ascii_tolower( *b ) )
 			return FALSE;
 		
@@ -1148,5 +1148,5 @@
 				{
 					n = strlen( value ) - 1;
-					while( isspace( value[n] ) )
+					while( g_ascii_isspace( value[n] ) )
 						n --;
 					g_string_append_len( info, value, n + 1 );
Index: protocols/skype/skype.c
===================================================================
--- protocols/skype/skype.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/skype/skype.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
  *  USA.
  */
@@ -514,5 +514,5 @@
 				char *iptr = sd->info_sex;
 				while (*iptr++)
-					*iptr = tolower(*iptr);
+					*iptr = g_ascii_tolower(*iptr);
 				g_string_append_printf(st,
 					"Gender: %s\n", sd->info_sex);
Index: protocols/twitter/twitter.c
===================================================================
--- protocols/twitter/twitter.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/twitter/twitter.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -459,7 +459,7 @@
 
 			strcpy(pin, message);
-			for (s = pin + sizeof(pin) - 2; s > pin && isspace(*s); s--)
+			for (s = pin + sizeof(pin) - 2; s > pin && g_ascii_isspace(*s); s--)
 				*s = '\0';
-			for (s = pin; *s && isspace(*s); s++) {
+			for (s = pin; *s && g_ascii_isspace(*s); s++) {
 			}
 
Index: protocols/yahoo/libyahoo2.c
===================================================================
--- protocols/yahoo/libyahoo2.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/libyahoo2.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -44,5 +44,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo.c
===================================================================
--- protocols/yahoo/yahoo.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo2.h
===================================================================
--- protocols/yahoo/yahoo2.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo2.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo2_callbacks.h
===================================================================
--- protocols/yahoo/yahoo2_callbacks.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo2_callbacks.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo2_types.h
===================================================================
--- protocols/yahoo/yahoo2_types.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo2_types.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo_debug.h
===================================================================
--- protocols/yahoo/yahoo_debug.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo_debug.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo_httplib.c
===================================================================
--- protocols/yahoo/yahoo_httplib.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo_httplib.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
@@ -152,5 +152,5 @@
 static int isurlchar(unsigned char c)
 {
-	return (isalnum(c));
+	return (g_ascii_isalnum(c));
 }
 
Index: protocols/yahoo/yahoo_httplib.h
===================================================================
--- protocols/yahoo/yahoo_httplib.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo_httplib.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo_list.h
===================================================================
--- protocols/yahoo/yahoo_list.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo_list.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -17,5 +17,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo_util.c
===================================================================
--- protocols/yahoo/yahoo_util.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo_util.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: protocols/yahoo/yahoo_util.h
===================================================================
--- protocols/yahoo/yahoo_util.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ protocols/yahoo/yahoo_util.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -16,5 +16,5 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
Index: query.c
===================================================================
--- query.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ query.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: query.h
===================================================================
--- query.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ query.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: root_commands.c
===================================================================
--- root_commands.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ root_commands.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: set.c
===================================================================
--- set.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ set.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -226,5 +226,5 @@
 	
 	for( ; *s; s ++ )
-		if( !isdigit( *s ) )
+		if( !g_ascii_isdigit( *s ) )
 			return SET_INVALID;
 	
Index: set.h
===================================================================
--- set.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ set.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: storage.c
===================================================================
--- storage.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ storage.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -22,6 +22,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: storage.h
===================================================================
--- storage.h	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ storage.h	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: storage_xml.c
===================================================================
--- storage_xml.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ storage_xml.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
Index: unix.c
===================================================================
--- unix.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ unix.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -20,6 +20,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 

Index: lib/misc.c
===================================================================
--- lib/misc.c	(revision bc7a0d46e36a819755ca3f2b38194fb11eca0dd9)
+++ lib/misc.c	(revision 1065dd4f38c81c83934ba51526471072837700ae)
@@ -27,6 +27,6 @@
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
@@ -163,5 +163,5 @@
 	while( *in )
 	{
-		if( *in == '<' && ( isalpha( *(in+1) ) || *(in+1) == '/' ) )
+		if( *in == '<' && ( g_ascii_isalpha( *(in+1) ) || *(in+1) == '/' ) )
 		{
 			/* If in points at a < and in+1 points at a letter or a slash, this is probably
@@ -198,5 +198,5 @@
 		{
 			cs = ++in;
-			while( *in && isalpha( *in ) )
+			while( *in && g_ascii_isalpha( *in ) )
 				in ++;
 			
@@ -314,5 +314,5 @@
 	for( i = j = 0; t[i]; i ++, j ++ )
 	{
 		/* Warning: isalnum() is locale-aware, so don't use it here! */
 		if( ( t[i] >= 'A' && t[i] <= 'Z' ) ||
 		    ( t[i] >= 'a' && t[i] <= 'z' ) ||
@@ -490,5 +490,5 @@
 	
 	while( *value )
-		if( !isdigit( *value ) )
+		if( !g_ascii_isdigit( *value ) )
 			return 0;
 		else
@@ -314,5 +314,5 @@
 	for( i = j = 0; t[i]; i ++, j ++ )
 	{
-		/* Warning: isalnum() is locale-aware, so don't use it here! */
+		/* Warning: g_ascii_isalnum() is locale-aware, so don't use it here! */
 		if( ( t[i] >= 'A' && t[i] <= 'Z' ) ||
 		    ( t[i] >= 'a' && t[i] <= 'z' ) ||